Skip to contents

Creates a data.frame() that contains the hexadecimal colour codes that correspond with the integer values to display the map colours as published by ABARES for the Catchment Level Land Use (clum) data. Values are derived from the .qml file provided by ABARES.

Usage

.create_clum_50m_coltab()

Examples

.apply_clum_50m_col_df()
#> Error in .apply_clum_50m_col_df(): could not find function ".apply_clum_50m_col_df"