Skip to contents

An internal function used by read_nlum_terra() and read_nlum_stars() that downloads national level land use data GeoTIFF file.

Usage

.get_nlum(.data_set, .x)

Arguments

.data_set

A string value indicating the GeoTIFF desired for download. One of:

Y201011

Land use of Australia 2010–11

Y201516

Land use of Australia 2015–16

Y202021

Land use of Australia 2020–21

C201121

Land use of Australia change

T201011

Land use of Australia 2010–11 thematic layers

T201516

Land use of Australia 2015–16 thematic layers

T202021

Land use of Australia 2020–21 thematic layers

P201011

Land use of Australia 2010–11 agricultural commodities probability grids

P201516

Land use of Australia 2015–16 agricultural commodities probability grids

P202021

Land use of Australia 2020–21 agricultural commodities probability grids

.

Value

An invisible NULL called for its side effect of downloading the desired file.

References

ABARES 2024, Land use of Australia 2010–11 to 2020–21, Australian Bureau of Agricultural and Resource Economics and Sciences, Canberra, November, CC BY 4.0. doi:10.25814/w175-xh85 .

Examples

.get_nlum(.data_set = "Y202021")
#> Error in .get_nlum(.data_set = "Y202021"): could not find function ".get_nlum"