Learn R Programming

read.abares (version 2.0.0)

print_topsoil_thickness_metadata: Prints the text file Metadata for ABARES' Topsoil Thickness for "Australian Areas of Intensive Agriculture of Layer 1"

Description

Prints the complete set of metadata associated with the soil thickness data in your R console. For including the metadata in documents or other methods outside of R, see .get_topsoil_thickness() for an example using pander::pander() to print the metadata.

Usage

print_topsoil_thickness_metadata(x = NULL)

Value

Nothing, called for its side effects, it prints the complete metadata file to the R console.

Arguments

x

An optional file path to a zip file containing the topsoil thickness data from ABARES. If left as NULL, the default value, a copy will be downloaded from the ABARES website.

References

<https://data.agriculture.gov.au/geonetwork/srv/eng/catalog.search#/metadata/faa9f157-8e17-4b23-b6a7-37eb7920ead6.

See Also

Other topsoil thickness: read_topsoil_thickness_stars(), read_topsoil_thickness_terra()

Examples

Run this code
if (FALSE) { # interactive()
print_print_topsoil_thickness_metadata()
}

Run the code above in your browser using DataLab