This page documents the global options used by the read.abares package.
The following options can be set via [options()] to control package behavior:
read.abares.user_agentCharacter string to set a custom user agent
for web requests. Default is
read.abares R package {version no.} https://github.com/ropensci/read.abares.
read.abares.timeoutInteger providing the timeout in seconds for
download operations. Default is 2000.
read.abares.timeout_connectInteger providing the connection
timeout in seconds. Default is 20.
read.abares.max_triesInteger providing the number of times to
retry download before giving up. Default is 3.
read.abares.verbositySet the desired level of verbosity.
"quiet" - no messages at all but errors will be reported,
"minimal" - warnings and errors only reported,
"verbose" - full messages including downloading, importing files, etc. reported.
These options can be set globally using:
options(read.abares.user_agent = "myCustomUserAgent") or
read.abares_options(read.abares.user_agent = "myCustomUserAgent")[options()]: R:options()
Other read.abares-options:
read.abares_options()