Skip to contents

Downloads and imports agricultural data from the Australian Bureau of Agricultural and Resource Economics and Sciences (ABARES) https://www.agriculture.gov.au/abares and the Australian Bureau of Statistics (ABS) https://www.abs.gov.au. Supports multiple data formats including spreadsheets, comma‑separated value (CSV) files, and geospatial data such as shapefiles and GeoTIFFs. Covers topics such as broadacre crops, livestock, soils, commodities and related agricultural information. The package standardises field names and data formats to improve interoperability and simplify analysis. It also streamlines the import of geospatial data and corrects common issues found in these data sources upon loading.

Author

Maintainer: Adam H. Sparks adamhsparks@gmail.com (ORCID)

Authors:

Other contributors:

  • Curtin University (ROR) (http://www.curtin.edu.au/) [copyright holder]

  • Jacob Wujciak-Jens jacob@wujciak.de (ORCID) (Assisted with troubleshooting formatting in documentation to display '<' and '>' properly) [contributor]

  • Nicholas Potter econpotter@gmail.com (ORCID) (rOpenSci Review https://github.com/ropensci/software-review/issues/667) [reviewer]

  • María Paula Caldas mpaulacaldas@gmail.com (ORCID) (rOpenSci Review https://github.com/ropensci/software-review/issues/667) [reviewer]