Creates the user-agent string for read.abares for default values based on whether the use is CI/development or interactive use.
Value
A character string to be used by httr2 as a user-agent.
Creates the user-agent string for read.abares for default values based on whether the use is CI/development or interactive use.
A character string to be used by httr2 as a user-agent.