Learn R Programming

read.abares (version 2.0.0)

read_abares_trade_regions: Read "Trade Data Regions" from the ABARES Trade Dashboard

Description

Fetches and imports ABARES "Trade Data Regions".

Usage

read_abares_trade_regions(x = NULL)

Value

A data.table object of the ABARES trade data regions.

Arguments

x

A file path providing the file with the data to be imported. The file is assumed to be unarchived (i.e., still zipped). This function does not provide any checking whether this function is the proper function for the provided file. Defaults to NULL, assuming that the file will be downloaded in the active R session.

References

https://daff.ent.sirsidynix.net.au/client/en_AU/search/asset/1033841/0

See Also

Other Trade: read_abares_trade()

Examples

Run this code
if (FALSE) { # interactive()
trade_regions <- read_abares_trade_regions()

trade_regions
}

Run the code above in your browser using DataLab