Learn R Programming

read.abares (version 2.0.0)

read_abs_horticulture_data: Get ABS' Horticulture Crops Production and Value by Australia, State and Territory by Year

Description

Automates downloading and importing of ABS horticulture crop production data. Please view the comments embedded in the spreadsheets themselves (that really should be columns of comments on the data) for important information.

Usage

read_abs_horticulture_data(year = "latest", x = NULL)

Value

A data.table::data.table() object of the requested data.

Arguments

year

A string value providing the year of interest to download. Formatted as "2022-23" or "2023-24" or use "latest" for the most recent release available. Defaults to "latest".

x

A file path providing the file with the data to be imported. The file is assumed to be unarchived (i.e., still zipped). This function does not provide any checking whether this function is the proper function for the provided file. Defaults to NULL, assuming that the file will be downloaded in the active R session.

Details

Technically these data are from the Australian Bureau of Statistics (ABS, not ABARES, but the data is agricultural and so it's serviced in this package.

References

https://www.abs.gov.au/statistics/industry/agriculture/australian-agriculture-horticulture.

See Also

Other ABS: read_abs_broadacre_data(), read_abs_livestock_data()

Examples

Run this code
if (FALSE) { # interactive()
horticulture_data <- read_abs_horticulture_data()
horticulture_data
}

Run the code above in your browser using DataLab