Learn R Programming

read.abares (version 2.0.0)

read_estimates_by_performance_category: Read ABARES' "Estimates by Performance Category" Data

Description

Fetches and imports ABARES estimates by performance category data.

Usage

read_estimates_by_performance_category(x = NULL)

read_est_by_perf_cat(x = NULL)

Value

A data.table::data.table() object.

Arguments

x

A file path providing the file with the data to be imported. The file is assumed to be unarchived (i.e., still zipped). This function does not provide any checking whether this function is the proper function for the provided file. Defaults to NULL, assuming that the file will be downloaded in the active R session.

References

https://www.agriculture.gov.au/abares/data/farm-data-portal#data-download.

See Also

Other Estimates: read_estimates_by_size(), read_historical_national_estimates(), read_historical_regional_estimates(), read_historical_state_estimates()

Examples

Run this code
if (FALSE) { # interactive()

read_estimates_by_performance_category()

# or shorter
read_est_by_perf_cat()
}

Run the code above in your browser using DataLab