Learn R Programming

read.abares (version 2.0.0)

read_historical_state_estimates: Read ABARES' "Historical State Estimates"

Description

Fetches and imports ABARES "Historical State Estimates" data.

Usage

read_historical_state_estimates(x = NULL)

read_hist_st_est(x = NULL)

Value

A data.table::data.table() object with the Variable field as the key.

Arguments

x

A file path providing the file with the data to be imported. The file is assumed to be unarchived (i.e., still zipped). This function does not provide any checking whether this function is the proper function for the provided file. Defaults to NULL, assuming that the file will be downloaded in the active R session.

References

https://www.agriculture.gov.au/abares/data/farm-data-portal#data-download.

See Also

Other Estimates: read_estimates_by_performance_category(), read_estimates_by_size(), read_historical_national_estimates(), read_historical_regional_estimates()

Examples

Run this code
if (FALSE) { # interactive()
read_historical_state_estimates()

# or shorter
read_hist_st_est()
}

Run the code above in your browser using DataLab