Download and import national scale "Land Use of Australia v7" GeoTIFFs as
categorical terra::rast() objects.
read_nlum_terra(data_set = NULL, x = NULL, ...)A terra
SpatRaster object that may be one or many layers
depending upon the requested data set.
A string value indicating the GeoTIFF desired for download. One of:
Land use of Australia 2010–11
Land use of Australia 2015–16
Land use of Australia 2020–21
Land use of Australia change
Land use of Australia 2010–11 thematic layers
Land use of Australia 2015–16 thematic layers
Land use of Australia 2020–21 thematic layers
Land use of Australia 2010–11 agricultural commodities probability grids
Land use of Australia 2015–16 agricultural commodities probability grids
Land use of Australia 2020–21 agricultural commodities probability grids
.
This argument is ignored if x is provided.
A character string of a file path to a local zip file that has
been downloaded outside of R that contains the NLUM data.
This argument is ignored if data_set is provided.
Other arguments passed to terra::rast().
From the ABARES website: "The Land use of Australia 2010–11 to 2020–21 data package consists of seamless continental rasters that present land use at national scale for 2010–11, 2015–16 and 2020–21 and the associated change between each target period. Non-agricultural land uses are mapped using 7 thematic layers, derived from existing datasets provided by state and territory jurisdictions and external agencies. These 7 layers are: protected areas, topographic features, land tenure, forest type, catchment scale land use, urban boundaries, and stock routes. The agricultural land uses are based on the Australian Bureau of Statistics’ 2010–11, 2015–16 and 2020–21 agricultural census data; with spatial distributions modelled using Terra Moderate Resolution Imaging Spectroradiometer (MODIS) satellite imagery and training data, assisted by spatial constraint layers for cultivation, horticulture, and irrigation. Land use is specified according to the Australian Land Use and Management (ALUM) Classification version 8. The same method is applied to all target periods using representative national datasets for each period, where available. All rasters are in GeoTIFF format with geographic coordinates in Geocentric Datum of Australian 1994 (GDA94) and a 0.002197 degree (~250 metre) cell size. The Land use of Australia 2010–11 to 2020–21 data package is a product of the Australian Collaborative Land Use and Management Program. This data package replaces the Land use of Australia 2010–11 to 2015–16 data package, with updates to these time periods." -- ABARES, 2024-11-28
ABARES 2024, Land use of Australia 2010–11 to 2020–21, Australian Bureau of Agricultural and Resource Economics and Sciences, Canberra, November, CC BY 4.0. tools:::Rd_expr_doi("10.25814/w175-xh85").
Other nlum:
read_nlum_stars(),
view_clum_metadata_pdf(),
view_nlum_metadata_pdf()
if (FALSE) { # interactive()
nlum_terra <- read_nlum_terra(data_set = "Y202021")
nlum_terra
plot(nlum_terra)
}
Run the code above in your browser using DataLab