Learn R Programming

read.abares (version 2.0.0)

view_clum_metadata_pdf: Displays the PDF Metadata for ABARES' "Catchment Land Use" (CLUM) Raster Files in a Native Viewer

Description

Each "Catchment Land Use" (CLUM) raster file comes with a PDF of metadata. This function will open and display that file using the native PDF viewer for any system with a graphical user interface and PDF viewer configured. If the file does not exist locally, it will be fetched and displayed.

Usage

view_clum_metadata_pdf(commodities = FALSE)

Value

An invisible NULL. Called for its side-effects, opens the system's native PDF viewer to display the requested metadata PDF

document.

Arguments

commodities

A Boolean value that indicates whether to download the catchment land scale use metadata for commodities. Defaults to FALSE, downloading the "Catchment Land Scale Use Metadata".

See Also

Other nlum: read_nlum_stars(), read_nlum_terra(), view_nlum_metadata_pdf()

Examples

Run this code
if (FALSE) { # interactive()
view_clum_metadata_pdf()
}

Run the code above in your browser using DataLab