Find Which Financial Years Data are Available
Source:R/parse_abs_production_data.R
dot-find_years.RdGrabs the ABS website and uses a regexp to find what financial years are available for download.

R/parse_abs_production_data.R
dot-find_years.RdGrabs the ABS website and uses a regexp to find what financial years are available for download.