Used by the read_agfd family of functions, downloads the "Australian
Gridded Farm Data" (AGFD) data.
Arguments
- .fixed_prices
Download historical climate and prices or historical climate and fixed prices as described in (Hughes et al. 2022).
- .yyyy
Returns only data for the specified year or years for climate data (fixed prices) or the years for historical climate and prices depending upon the setting of
.fixed_prices. Note that this will still download the entire data set, that cannot be avoided, but will only return the requested year(s) in your R session. Valid years are from 1991 to 2023 inclusive.