An internal function used by read_clum_terra() and read_clum_stars() that
downloads catchment level land use data files.
Land Use: doi:10.25814/2w2p-ph98 ,
Commodities: doi:10.25814/zfjz-jt75 .
Value
A vector of filenames of a geotiff file or files related to Australian catchment scale land use data.
References
ABARES 2024, Catchment Scale Land Use of Australia – Update December 2023 version 2, Australian Bureau of Agricultural and Resource Economics and Sciences, Canberra, June, CC BY 4.0, DOI: doi:10.25814/2w2p-ph98 .