print_topsoil_thickness_metadata: Prints the text file Metadata for ABARES' Topsoil Thickness for "Australian Areas of Intensive Agriculture of Layer 1"
Description
Prints the complete set of metadata associated with the soil thickness
data in your R console. For including the metadata in documents or other
methods outside of R, see .get_topsoil_thickness() for an example using
pander::pander() to print the metadata.
Usage
print_topsoil_thickness_metadata(x = NULL)
Value
Nothing, called for its side effects, it prints the complete
metadata file to the R console.
Arguments
x
An optional file path to a zip file containing the topsoil thickness
data from ABARES. If left as NULL, the default value, a copy
will be downloaded from the ABARES website.