Learn R Programming

read.abares (version 2.0.0)

read.abares-package: read.abares: Read Data from the Australian Bureau of Agricultural and Resource Economics and Sciences (ABARES) and Australian Bureau of Statistics (ABS)

Description

logo

Download and import agricultural data from the Australian Bureau of Agricultural and Resource Economics and Sciences (ABARES) https://www.agriculture.gov.au/abares and Australian Bureau of Statistics (ABS) https://www.abs.gov.au. Data types serviced include spreadsheets, comma separated value (CSV) files, geospatial data including shape files and geotiffs covering topics including broadacre crops, livestock, soil data, commodities and more. Unifies field names and formats for data interoperability making analysis easier by standardising names between data formats. Also simplifies importing geospatial data as well as correcting issues in the geospatial data upon import.

Arguments

Author

Maintainer: Adam H. Sparks adamhsparks@gmail.com (ORCID)

Other contributors:

  • Curtin University (ROR) (http://www.curtin.edu.au/) [funder, copyright holder]

  • Grains Research and Development Corporation (ROR) (GRDC Project CUR2210-005OPX (AAGI-CU)) [funder, copyright holder]

  • Jacob Wujciak-Jens jacob@wujciak.de (ORCID) (Assisted with troubleshooting formatting in documentation to display '<' and '>' properly) [contributor]

  • Nicholas Potter econpotter@gmail.com (ORCID) (rOpenSci Review https://github.com/ropensci/software-review/issues/667) [reviewer]

  • María Paula Caldas mpaulacaldas@gmail.com (ORCID) (rOpenSci Review https://github.com/ropensci/software-review/issues/667) [reviewer]

See Also