powered by
A convenience function to get or set options used by read.abares.
read.abares_options(...)
A list of current option values.
Named options to set, or no arguments to retrieve current values.
Other read.abares-options: read.abares-options
read.abares-options
# See currently set options for {read.abares} read.abares_options() # Set to "verbosity" to "quiet" suppress messages read.abares_options(read.abares.verbosity = "quiet") read.abares_options()
Run the code above in your browser using DataLab