Learn R Programming

read.abares (version 2.0.0)

read_aagis_regions: Read ABARES' "Australian Agricultural and Grazing Industries Survey" (AAGIS) Region Mapping Files

Description

Download import the "Australian Agricultural and Grazing Industries Survey" (AAGIS) regions geospatial shapefile.

Usage

read_aagis_regions(x = NULL)

Value

An sf object of the AAGIS regions.

Arguments

x

A file path providing the file with the data to be imported. The file is assumed to be unarchived (i.e., still zipped). This function does not provide any checking whether this function is the proper function for the provided file. Defaults to NULL, assuming that the file will be downloaded in the active R session.

References

https://www.agriculture.gov.au/abares/research-topics/surveys/farm-definitions-methods#regions.

Examples

Run this code
if (FALSE) { # interactive()
aagis <- read_aagis_regions()

plot(aagis)
}

Run the code above in your browser using DataLab