Learn R Programming

read.abares (version 2.0.0)

read_abares_trade: Read Data from the ABARES Trade Dashboard

Description

Fetches and imports ABARES trade data. As the data x is large, ~1.4GB uncompressed CSV x.

Usage

read_abares_trade(x = NULL)

Value

A data.table object of the ABARES trade data.

Arguments

x

A file path providing the file with the data to be imported. The file is assumed to be unarchived (i.e., still zipped). This function does not provide any checking whether this function is the proper function for the provided file. Defaults to NULL, assuming that the file will be downloaded in the active R session.

References

https://www.agriculture.gov.au/abares/research-topics/trade/dashboard

See Also

Other Trade: read_abares_trade_regions()

Examples

Run this code
if (FALSE) { # interactive()
trade <- read_abares_trade()

trade
}

Run the code above in your browser using DataLab