read_topsoil_thickness_terra: Read ABARES' "Soil Thickness for Australian Areas of Intensive Agriculture of Layer 1" with terra
Description
Read "Soil Thickness for Australian Areas of Intensive Agriculture of Layer
1" as a terra::rast() object.
Usage
read_topsoil_thickness_terra(x = NULL, ...)
Value
A terra::rast() object of the "Soil Thickness for Australian Areas
of Intensive Agriculture of Layer 1".
Arguments
x
A file path providing the file with the data to be imported. The
file is assumed to be unarchived (i.e., still zipped). This function does
not provide any checking whether this function is the proper function for
the provided file. Defaults to NULL, assuming that the file will be
downloaded in the active R session.